@@ -1,10 +1,21 @@
-__version__ = '000.000.055'
+__version__ = '000.000.056'
+
+__release_day__ = 2
+__release_month_num__ = 1
+__release_year__ = 2021
+
+import datetime
+__release_date_object__ = datetime.date(__release_year__, __release_month_num__, __release_day__)
+del datetime
+__release_date__ = __release_date_object__.__format__('%d %B %Y')
+__release_month_name__ = __release_date_object__.__format__('%B')
+
 __author__ = 'Calafiore Carmelo'
 __author_email__ = 'c.calafiore@essex.ac.uk'
 __maintainer_email__ = 'c.calafiore@essex.ac.uk'
 __all__ = [
-    'array', 'check_args', 'clock', 'combinations', 'directory', 'download',
-    'format_args', 'image', 'maths', 'mixamo', 'nn', 'plot', 'preprocessing', 'shutdown', 'stats',
+    'array', 'check', 'clock', 'combinations', 'directory', 'download',
+    'format', 'image', 'maths', 'mixamo', 'nn', 'pkl', 'plot', 'preprocessing', 'shutdown', 'stats',
     'stimulation', 'strings', 'txt']
 
 
