@@ -1,7 +1,7 @@
 import numpy as np
 import math
 import itertools
-from . import format_args as cc_format_args
+from . import format as cc_format
 from . import array as cc_array
 from . import maths as cc_maths
 
@@ -183,15 +183,25 @@ def conditions_to_combinations_on_the_fly(
 
         if order_outputs[o] == 'v':
 
-            dtype_np = np.dtype(dtype)
-            if dtype_np.kind == 'U':
-                combination_values_i = np.empty(n_variables, dtype='O')
+            if dtype is None:
+                combination_values_i = [None] * n_variables
+                dtype_np = None
             else:
-                combination_values_i = np.empty(n_variables, dtype=dtype)
+                dtype_np = np.dtype(dtype)
+                if dtype_np.kind == 'U':
+                    combination_values_i = np.empty(n_variables, dtype='O')
+                else:
+                    combination_values_i = np.empty(n_variables, dtype=dtype)
 
             for v in range(n_variables):
                 combination_values_i[v] = conditions[v][combination_indexes_i[v]]
 
+            if dtype_np is None:
+                combination_values_i = np.asarray(combination_values_i)
+                dtype_np = combination_values_i.dtype
+                if dtype_np.kind == 'U':
+                    combination_values_i = combination_values_i.astype('O')
+
             if dtype_np.kind == 'U':
                 outputs_i[o] = combination_values_i.astype('U')
             else:
@@ -469,13 +479,13 @@ def conditions_to_phases_of_blocks_of_shuffled_combinations(
         variables_split=variables_split,
         n_repetitions_variables_repeated_per_shuffle=n_repetitions_variables_repeated_per_shuffle)
 
-    dict_arguments = cc_format_args.format_shape_arguments(dict_arguments, n_phases)
+    dict_arguments = cc_format.format_shape_arguments(dict_arguments, n_phases)
     n_repetitions_combinations = dict_arguments['n_repetitions_combinations']
     n_repetitions_variables_repeated_per_block = dict_arguments['n_repetitions_variables_repeated_per_block']
     variables_split = dict_arguments['variables_split']
     n_repetitions_variables_repeated_per_shuffle = dict_arguments['n_repetitions_variables_repeated_per_shuffle']
 
-    # dict_arguments = cc_format_args.format_shape_arguments(dict_arguments, n_phases)
+    # dict_arguments = cc_format.format_shape_arguments(dict_arguments, n_phases)
     # locals().update(dict_arguments)
 
     phases_of_blocks_of_shuffled_combinations = np.empty(n_phases, dtype=object)
@@ -504,7 +514,7 @@ def n_conditions_to_phases_of_blocks_of_shuffled_combinations(
         variables_split=variables_split,
         n_repetitions_variables_repeated_per_shuffle=n_repetitions_variables_repeated_per_shuffle)
 
-    dict_arguments = cc_format_args.format_shape_arguments(dict_arguments, n_phases)
+    dict_arguments = cc_format.format_shape_arguments(dict_arguments, n_phases)
 
     n_repetitions_combinations = dict_arguments['n_repetitions_combinations']
     n_repetitions_variables_repeated_per_block = dict_arguments['n_repetitions_variables_repeated_per_block']
