@@ -2,8 +2,8 @@ import numpy as np
 from matplotlib import pyplot as plt
 import matplotlib.colors
 from .combinations import n_conditions_to_combinations as cc_n_conditions_to_combinations
-from . import format_args as cc_format_args
-from . import check_args as cc_check_args
+from . import format as cc_format
+from . import check as cc_check
 # from . import strings as cc_strings
 
 my_dpi = 100
@@ -367,15 +367,15 @@ def points_1_format_multi_plots_1_figure(
         if not isinstance(axes, dict):
             raise TypeError('The type of "axes" has to be dict')
         else:
-            keys_axes, axes_y = cc_format_args.dict_to_key_array_and_value_array(axes)
+            keys_axes, axes_y = cc_format.dict_to_key_array_and_value_array(axes)
             axes_negative = axes_y < 0
             axes_y[axes_negative] += n_dim_y
             for k in keys_axes[axes_negative]:
                 axes[k] += n_dim_y
 
-        cc_check_args.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
+        cc_check.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
             axes, keys_axes_expected, values_axes_expected, name_dictionary='axes')
-        cc_check_args.values_are_not_repeated(axes, name_dictionary='axes')
+        cc_check.values_are_not_repeated(axes, name_dictionary='axes')
 
         n_rows, n_columns = shape_y[axes_subplots]
         axes_subplots_sort = np.sort(axes_subplots)
@@ -398,15 +398,15 @@ def points_1_format_multi_plots_1_figure(
         if not isinstance(axes, dict):
             raise TypeError('The type of "axes" has to be dict')
         else:
-            keys_axes, axes_x = cc_format_args.dict_to_key_array_and_value_array(axes)
+            keys_axes, axes_x = cc_format.dict_to_key_array_and_value_array(axes)
             axes_negative = axes_x < 0
             axes_x[axes_negative] += n_dim_x
             for k in keys_axes[axes_negative]:
                 axes[k] += n_dim_x
 
-        cc_check_args.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
+        cc_check.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
             axes, keys_axes_expected, values_axes_expected, name_dictionary='axes')
-        cc_check_args.values_are_not_repeated(axes, name_dictionary='axes')
+        cc_check.values_are_not_repeated(axes, name_dictionary='axes')
 
         n_rows, n_columns = shape_x[axes_subplots]
         axes_subplots_sort = np.sort(axes_subplots)
@@ -466,7 +466,7 @@ def points_1_format_multi_plots_1_figure(
 
     n_kwargs = len(kwargs)
     if n_kwargs > 0:
-        kwargs = cc_format_args.format_shape_arguments(kwargs, shape_subplots)
+        kwargs = cc_format.format_shape_arguments(kwargs, shape_subplots)
         index_kwargs = np.empty(n_axes_subplots, dtype=object)
         index_kwargs[:] = slice(None)
 
@@ -752,15 +752,15 @@ def heatmap(
         dict_axes = dict(zip(keys_axes_expected, values_axes_expected))
     else:
 
-        keys_axes, axes_data = cc_format_args.dict_to_key_array_and_value_array(dict_axes)
+        keys_axes, axes_data = cc_format.dict_to_key_array_and_value_array(dict_axes)
         axes_negative = axes_data < 0
         axes_data[axes_negative] += n_axes
         for k in keys_axes[axes_negative]:
             dict_axes[k] += n_axes
 
-        cc_check_args.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
+        cc_check.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
             dict_axes, keys_axes_expected, values_axes_expected, name_dictionary='dict_axes')
-        cc_check_args.values_are_not_repeated(dict_axes, name_dictionary='dict_axes')
+        cc_check.values_are_not_repeated(dict_axes, name_dictionary='dict_axes')
 
         if dict_axes['x'] < dict_axes['y']:
             data = data.T
@@ -1078,15 +1078,15 @@ def heatmaps_in_1_figure(
         dict_axes = dict(zip(keys_axes_expected, values_axes_expected))
     else:
 
-        keys_axes, axes_data = cc_format_args.dict_to_key_array_and_value_array(dict_axes)
+        keys_axes, axes_data = cc_format.dict_to_key_array_and_value_array(dict_axes)
         axes_negative = axes_data < 0
         axes_data[axes_negative] += n_axes
         for k in keys_axes[axes_negative]:
             dict_axes[k] += n_axes
 
-        cc_check_args.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
+        cc_check.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
             dict_axes, keys_axes_expected, values_axes_expected, name_dictionary='dict_axes')
-        cc_check_args.values_are_not_repeated(dict_axes, name_dictionary='dict_axes')
+        cc_check.values_are_not_repeated(dict_axes, name_dictionary='dict_axes')
 
     axes_subplots = np.asarray([dict_axes['rows'], dict_axes['columns']], dtype=int)
     n_axes_subplots = axes_subplots.size
@@ -1167,7 +1167,7 @@ def heatmaps_in_1_figure(
 
     n_kwargs = len(kwargs)
     if n_kwargs > 0:
-        kwargs = cc_format_args.format_shape_arguments(kwargs, shape_subplots)
+        kwargs = cc_format.format_shape_arguments(kwargs, shape_subplots)
         index_kwargs = np.empty(n_axes_subplots, dtype=object)
         index_kwargs[:] = slice(None)
 
@@ -1278,15 +1278,15 @@ def heatmaps_in_multi_figures(
         dict_axes = dict(zip(keys_axes_expected, values_axes_expected))
     else:
 
-        keys_axes, axes_data = cc_format_args.dict_to_key_array_and_value_array(dict_axes)
+        keys_axes, axes_data = cc_format.dict_to_key_array_and_value_array(dict_axes)
         axes_negative = axes_data < 0
         axes_data[axes_negative] += n_axes
         for k in keys_axes[axes_negative]:
             dict_axes[k] += n_axes
 
-        cc_check_args.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
+        cc_check.keys_necessary_known_and_values_necessary_known_exist_and_other_keys_and_values_do_not_exist(
             dict_axes, keys_axes_expected, values_axes_expected, name_dictionary='dict_axes')
-        cc_check_args.values_are_not_repeated(dict_axes, name_dictionary='dict_axes')
+        cc_check.values_are_not_repeated(dict_axes, name_dictionary='dict_axes')
 
     axes_subplots = np.asarray([dict_axes['figures'], dict_axes['rows'], dict_axes['columns']], dtype=int)
     n_axes_subplots = axes_subplots.size
@@ -1330,7 +1330,7 @@ def heatmaps_in_multi_figures(
     if dict_axes['figures'] > dict_axes['columns']:
         axis_figures_in_kwargs += 1
 
-    dict_arguments = cc_format_args.format_shape_arguments(
+    dict_arguments = cc_format.format_shape_arguments(
         dict(hspace=hspace, add_letters_to_titles=add_letters_to_titles,
              maximum_n_pixels_per_plot=maximum_n_pixels_per_plot,
              sharex=sharex, sharey=sharey),
@@ -1344,7 +1344,7 @@ def heatmaps_in_multi_figures(
 
     n_kwargs = len(kwargs)
     if n_kwargs > 0:
-        kwargs = cc_format_args.format_shape_arguments(kwargs, shape_subplots)
+        kwargs = cc_format.format_shape_arguments(kwargs, shape_subplots)
         index_kwargs = np.empty(n_axes_subplots, dtype=object)
         index_kwargs[:] = slice(None)
 
