@@ -1,6 +1,6 @@
 import numpy as np
-from ccalafiore.array import samples_in_arr1_are_in_arr2  # , advanced_indexing
-from ccalafiore.combinations import (
+from ...array import samples_in_arr1_are_in_arr2  # , advanced_indexing
+from ...combinations import (
     trials_to_conditions, conditions_to_n_conditions, n_conditions_to_combinations, conditions_to_combinations)
 
 # def from_2_arrays_new(
