@@ -3,6 +3,54 @@ from scipy.stats import t
 # from scipy.stats.stats import _ttest_finish
 from ..combinations import n_conditions_to_combinations, trials_to_n_conditions
 from ..array import samples_in_arr1_are_in_arr2
+from .. import maths as cc_maths
+
+
+def select_sum(exclude_nan=True):
+    if exclude_nan:
+        sum = np.nansum
+    else:
+        sum = np.sum
+    return sum
+
+
+def counter_excluding_nan_keeping_dims(scores, axis_samples):
+    n_samples = np.sum(cc_maths.is_not_nan(scores), axis=axis_samples, keepdims=True)
+    return n_samples
+
+
+def counter_excluding_nan_not_keeping_dims(scores, axis_samples):
+    n_samples = np.sum(cc_maths.is_not_nan(scores), axis=axis_samples, keepdims=False)
+    return n_samples
+
+
+# def counter_including_nan_keeping_dims(scores, axis_samples):
+#     n_samples = np.empty(scores.shape, dtype='i')
+#     n_samples[:] = scores.shape[axis_samples]
+#     return n_samples
+#
+#
+# def counter_including_nan_not_keeping_dims(scores, axis_samples):
+#     n_samples = scores.shape[axis_samples]
+#     return n_samples
+def counter_including_nan(scores, axis_samples):
+    n_samples = scores.shape[axis_samples]
+    return n_samples
+
+
+def select_counter(exclude_nan=True, keepdims=False):
+    if exclude_nan:
+        if keepdims:
+            counter = counter_excluding_nan_keeping_dims
+        else:
+            counter = counter_excluding_nan_not_keeping_dims
+    else:
+        counter = counter_including_nan
+        # if keepdims:
+        #     counter = counter_including_nan_keeping_dims
+        # else:
+        #     counter = counter_including_nan_not_keeping_dims
+    return counter
 
 
 def scores_to_diff_of_scores(scores, axis, delta=1, stride=1, keepdims=False):
@@ -63,7 +111,9 @@ def scores_to_diff_of_scores(scores, axis, delta=1, stride=1, keepdims=False):
     return diff_of_scores
 
 
-def scores_to_n_samples(scores, axis_samples, keepdims=False):
+def scores_to_n_samples(scores, axis_samples, keepdims=False, exclude_nan=True):
+
+    counter = select_counter(exclude_nan=exclude_nan, keepdims=keepdims)
 
     if scores.dtype == object:
 
@@ -98,8 +148,10 @@ def scores_to_n_samples(scores, axis_samples, keepdims=False):
             indexes_n_samples_tuple = tuple(indexes_n_samples)
             indexes_object_i_tuple = tuple(indexes_object_i)
 
-            n_samples[indexes_n_samples_tuple] = np.sum(np.logical_not(np.isnan(
-                scores[indexes_object_i_tuple])), axis=axis_samples, keepdims=keepdims)
+            n_samples[indexes_n_samples_tuple] = counter(scores[indexes_object_i_tuple], axis_samples=axis_samples)
+
+            # n_samples[indexes_n_samples_tuple] = np.sum(
+            #     cc_maths.is_not_nan(scores[indexes_object_i_tuple]), axis=axis_samples, keepdims=keepdims)
 
     else:
         shape_scores = np.asarray(scores.shape)
@@ -107,7 +159,7 @@ def scores_to_n_samples(scores, axis_samples, keepdims=False):
         if axis_samples < 0:
             axis_samples += n_axes_scores
 
-        n_samples = np.sum(np.logical_not(np.isnan(scores)), axis=axis_samples, keepdims=keepdims)
+        n_samples = counter(scores, axis_samples=axis_samples)
 
     return n_samples
 
@@ -182,18 +234,20 @@ def samples_to_percentages(data, axis_samples, axis_variables_table):
     return percentages
 
 
-def scores_to_df_of_variance_and_paired_t(scores, axis_samples, keepdims=False):
+def scores_to_df_of_variance_and_paired_t(scores, axis_samples, keepdims=False, exclude_nan=True):
 
-    n_samples = scores_to_n_samples(scores, axis_samples=axis_samples, keepdims=keepdims)
+    n_samples = scores_to_n_samples(scores, axis_samples=axis_samples, keepdims=keepdims, exclude_nan=exclude_nan)
     df = n_samples - 1
 
     return df
 
 
-def scores_to_means(scores, axes, keepdims=False):
+def scores_to_means(scores, axes, keepdims=False, exclude_nan=True):
 
     axes_means = axes
 
+    sum = select_sum(exclude_nan=exclude_nan)
+
     if scores.dtype == object:
 
         shape_object_scores = np.asarray(scores.shape)
@@ -243,8 +297,11 @@ def scores_to_means(scores, axes, keepdims=False):
 
             scores_tmp_i = scores[indexes_object_tuple_i]
             for a in axes_means:
-                n_samples = np.sum(np.logical_not(np.isnan(scores_tmp_i)), axis=a, keepdims=keepdims)
-                sum_of_scores = np.nansum(scores_tmp_i, axis=a, keepdims=keepdims)
+                n_samples = scores_to_n_samples(
+                    scores_tmp_i, axis_samples=a, keepdims=keepdims, exclude_nan=exclude_nan)
+                # n_samples = np.sum(cc_maths.is_not_nan(scores_tmp_i), axis=a, keepdims=keepdims)
+
+                sum_of_scores = sum(scores_tmp_i, axis=a, keepdims=keepdims)
                 scores_tmp_i = sum_of_scores / n_samples
 
             means[indexes_means_tuple_i] = scores_tmp_i
@@ -270,15 +327,19 @@ def scores_to_means(scores, axes, keepdims=False):
             # n_axes_means = 1
         scores_tmp = scores
         for a in axes_means:
-            sum_of_scores = np.nansum(scores_tmp, axis=a, keepdims=keepdims)
-            n_samples = np.sum(np.logical_not(np.isnan(scores_tmp)), axis=a, keepdims=keepdims)
+            n_samples = scores_to_n_samples(
+                scores_tmp, axis_samples=a, keepdims=keepdims, exclude_nan=exclude_nan)
+            # n_samples = np.sum(cc_maths.is_not_nan(scores_tmp), axis=a, keepdims=keepdims)
+            sum_of_scores = sum(scores_tmp, axis=a, keepdims=keepdims)
             scores_tmp = sum_of_scores / n_samples
         means = scores_tmp
 
     return means
 
 
-def scores_to_variances(scores, axis_samples, keepdims=False):
+def scores_to_variances(scores, axis_samples, keepdims=False, exclude_nan=True):
+
+    sum = select_sum(exclude_nan=exclude_nan)
 
     if scores.dtype == object:
 
@@ -313,17 +374,28 @@ def scores_to_variances(scores, axis_samples, keepdims=False):
             indexes_variances_tuple = tuple(indexes_variances)
             indexes_object_i_tuple = tuple(indexes_object_i)
 
-            n_samples = np.sum(np.logical_not(np.isnan(
-                scores[indexes_object_i_tuple])), axis=axis_samples, keepdims=True)
-            sum_of_scores = np.nansum(scores[indexes_object_i_tuple], axis=axis_samples, keepdims=True)
-            means = sum_of_scores / n_samples
+            n_samples = scores_to_n_samples(
+                scores[indexes_object_i_tuple], axis_samples=axis_samples, keepdims=True, exclude_nan=exclude_nan)
+            # n_samples = np.sum(cc_maths.is_not_nan(
+            #     scores[indexes_object_i_tuple]), axis=axis_samples, keepdims=True)
 
-            sum_of_squared_distances = np.nansum(
-                (scores[indexes_object_i_tuple] - means) ** 2,
-                axis=axis_samples, keepdims=keepdims)
+            sum_of_scores = sum(scores[indexes_object_i_tuple], axis=axis_samples, keepdims=True)
+            # sum_of_scores = np.nansum(scores[indexes_object_i_tuple], axis=axis_samples, keepdims=keepdims)
+
+            means = sum_of_scores / n_samples
+            # means = scores_to_means(
+            #     scores[indexes_object_i_tuple], axes=axis_samples, keepdims=keepdims, exclude_nan=exclude_nan)
+
+            sum_of_squared_distances = sum(
+                (scores[indexes_object_i_tuple] - means) ** 2, axis=axis_samples, keepdims=keepdims)
 
             if not keepdims:
-                n_samples = np.squeeze(n_samples, axis=axis_samples)
+                try:
+                    n_samples[axis_samples]
+                    n_samples = np.squeeze(n_samples, axis=axis_samples)
+                except TypeError:
+                    pass
+
             df = n_samples - 1
 
             variances[indexes_variances_tuple] = sum_of_squared_distances / df
@@ -335,41 +407,50 @@ def scores_to_variances(scores, axis_samples, keepdims=False):
         if axis_samples < 0:
             axis_samples += n_axes_scores
 
-        n_samples = np.sum(np.logical_not(np.isnan(scores)), axis=axis_samples, keepdims=True)
-        means = np.nansum(scores, axis=axis_samples, keepdims=True) / n_samples
-        sum_of_squared_distances = np.nansum((scores - means) ** 2, axis=axis_samples, keepdims=keepdims)
+        n_samples = scores_to_n_samples(scores, axis_samples=axis_samples, keepdims=True, exclude_nan=exclude_nan)
+        # n_samples = np.sum(cc_maths.is_not_nan(scores), axis=axis_samples, keepdims=True)
+        sum_of_scores = sum(scores, axis=axis_samples, keepdims=True)
+        means = sum_of_scores / n_samples
+        # means = np.nansum(scores, axis=axis_samples, keepdims=True) / n_samples
+        sum_of_squared_distances = sum((scores - means) ** 2, axis=axis_samples, keepdims=keepdims)
+        # sum_of_squared_distances = np.nansum((scores - means) ** 2, axis=axis_samples, keepdims=keepdims)
         if not keepdims:
-            n_samples = np.squeeze(n_samples, axis=axis_samples)
+            try:
+                n_samples[axis_samples]
+                n_samples = np.squeeze(n_samples, axis=axis_samples)
+            except TypeError:
+                pass
+
         df = n_samples - 1
         variances = sum_of_squared_distances / df
 
     return variances
 
 
-def scores_to_standard_deviations(scores, axis_samples, keepdims=False):
+def scores_to_standard_deviations(scores, axis_samples, keepdims=False, exclude_nan=True):
 
-    variances = scores_to_variances(scores, axis_samples, keepdims=keepdims)
+    variances = scores_to_variances(scores, axis_samples, keepdims=keepdims, exclude_nan=exclude_nan)
     standard_deviations = np.sqrt(variances)
 
     return standard_deviations
 
 
-def scores_to_standard_errors(scores, axis_samples, keepdims=False):
+def scores_to_standard_errors(scores, axis_samples, keepdims=False, exclude_nan=True):
 
     # shape_scores = np.asarray(scores.shape)
     # n_axes_scores = shape_scores.size
     # if axis_samples < 0:
     #     axis_samples += n_axes_scores
 
-    n_samples = scores_to_n_samples(scores, axis_samples, keepdims=keepdims)
-    variances = scores_to_variances(scores, axis_samples, keepdims=keepdims)
+    n_samples = scores_to_n_samples(scores, axis_samples, keepdims=keepdims, exclude_nan=exclude_nan)
+    variances = scores_to_variances(scores, axis_samples, keepdims=keepdims, exclude_nan=exclude_nan)
     std_error = np.sqrt(variances / n_samples)
 
     return std_error
 
 
 def scores_to_confidence_intervals(
-        scores, axis_samples, alpha=0.05, tails='2', keepdims=False):
+        scores, axis_samples, alpha=0.05, tails='2', keepdims=False, exclude_nan=True):
 
     confidence = 1 - alpha
 
@@ -378,8 +459,8 @@ def scores_to_confidence_intervals(
     # if axis_samples < 0:
     #     axis_samples += n_axes_scores
 
-    std_err = scores_to_standard_errors(scores, axis_samples, keepdims=keepdims)
-    df = scores_to_df_of_variance_and_paired_t(scores, axis_samples, keepdims=keepdims)
+    std_err = scores_to_standard_errors(scores, axis_samples, keepdims=keepdims, exclude_nan=exclude_nan)
+    df = scores_to_df_of_variance_and_paired_t(scores, axis_samples, keepdims=keepdims, exclude_nan=exclude_nan)
 
     shape_df = np.asarray(df.shape)
     indexes_df = n_conditions_to_combinations(shape_df)
@@ -400,3 +481,74 @@ def scores_to_confidence_intervals(
     h = std_err * t_critical
 
     return h
+
+
+def scores_to_local_mean(data, axis, n_neighbours, exclude_nan=True):
+
+    n_axes = len(data.shape)
+    if axis < 0:
+        axis += n_axes
+
+    I = data.shape[axis]
+
+    shape_means_local = list(data.shape)
+    shape_means_local[axis] = I - n_neighbours + 1
+
+    means_local = np.empty(shape_means_local, dtype='f')
+
+    indexes_means_local = np.empty(n_axes, dtype='O')
+    indexes_data = np.empty(n_axes, dtype='O')
+
+    for a in range(n_axes):
+        if a != axis:
+            indexes_means_local[a] = slice(0, means_local.shape[a], 1)
+            indexes_data[a] = slice(0, data.shape[a], 1)
+
+    for i in range(0, I - n_neighbours + 1, 1):
+        indexes_means_local[axis] = i
+        indexes_data[axis] = slice(i, i + n_neighbours, 1)
+        means_local[tuple(indexes_means_local)] = scores_to_means(
+            data[tuple(indexes_data)], axes=axis, keepdims=False, exclude_nan=exclude_nan)
+
+    return means_local
+
+
+def scores_to_value_frequencies(data, axis, value):
+
+    if cc_maths.is_nan(value):
+        arr_logical = cc_maths.is_nan(data)
+    else:
+        arr_logical = data == value
+
+    arr = np.sum(arr_logical, axis=axis, initial=0)
+    return arr
+
+
+def scores_to_local_value_frequencies(data, axis, n_neighbours, value):
+    n_axes = len(data.shape)
+    if axis < 0:
+        axis += n_axes
+
+    I = data.shape[axis]
+
+    shape_local_frequencies = list(data.shape)
+    shape_local_frequencies[axis] = I - n_neighbours + 1
+
+    local_frequencies = np.empty(shape_local_frequencies, dtype='i')
+
+    indexes_local_frequencies = np.empty(n_axes, dtype='O')
+    indexes_data = np.empty(n_axes, dtype='O')
+
+    for a in range(n_axes):
+        if a != axis:
+            indexes_local_frequencies[a] = slice(0, local_frequencies.shape[a], 1)
+            indexes_data[a] = slice(0, data.shape[a], 1)
+
+    for i in range(0, I - n_neighbours + 1, 1):
+        indexes_local_frequencies[axis] = i
+        indexes_data[axis] = slice(i, i + n_neighbours, 1)
+
+        local_frequencies[tuple(indexes_local_frequencies)] = scores_to_value_frequencies(
+            data[tuple(indexes_data)], axis, value)
+
+    return local_frequencies
